@@ -41,7 +41,7 @@ $key = '';
 //
 if( isset($params['defer']) && $params['defer'] == 1 ) {
   $defer = 1;
- }
+}
 
 //
 // Get the map information
@@ -49,7 +49,7 @@ if( isset($params['defer']) && $params['defer'] == 1 ) {
 $mapid = $key = $this->GetPreference('default_map',0);
 if( isset($params['map']) ) {
   if( !is_numeric($params['map']) ) {
-    $map = cggm2_map_operations::load_by_name($params['map']);
+    $map = cggm2_map_operations::load_by_name($params['map'],TRUE);
     if( is_object($map) ) $mapid = $key = $map->id;
   }
   else {
@@ -65,16 +65,12 @@ if( !$mapid ) {
   return;
 }
 
-if( !$map ) $map = cggm2_map_operations::load_by_id($mapid,true);
+if( !$map ) $map = cggm2_map_operations::load_by_id($mapid,TRUE);
 if( !$map ) {
   echo $this->DisplayErrorMessage($this->Lang('error_invalidparams'));
   return;
 }
 
-$mid = $map->get_id();
-
-cggm2_marker_operations::load_markers_for_map($map);
-
 // add attributes 
 if( is_array($this->_dyn_attrs) && isset($this->_dyn_attrs[$mapid]) &&
     count($this->_dyn_attrs[$mapid]) ) {
@@ -101,13 +97,13 @@ if( is_array($this->_dynamic_points) && isset($this->_dynamic_points[$key]) && c
 }
 
 // add kml layers
-if( is_array($this->_kml_files) && isset($this->_kml_files[$mid]) && count($this->_kml_files[$mid]) ) {
-  for( $i = 0; $i < count($this->_kml_files[$mid]); $i++ ) {
-    if( $this->_kml_files[$mid][$i] != '' ) {
-      $map->add_kml($this->_kml_files[$mid][$i]);
+if( is_array($this->_kml_files) && isset($this->_kml_files[$mapid]) && count($this->_kml_files[$mapid]) ) {
+  for( $i = 0; $i < count($this->_kml_files[$mapid]); $i++ ) {
+    if( $this->_kml_files[$mapid][$i] != '' ) {
+      $map->add_kml($this->_kml_files[$mapid][$i]);
     }
   }
-  unset($this->_kml_files[$mid]);
+  unset($this->_kml_files[$mapid]);
 }
 
 // add more parameters
