@@ -158,11 +158,15 @@ class cggm2_map_generator
 
   protected function _get_markers_as_data()
   {
+    $_fix_coord = function($num) {
+      return number_format($num,6,'.','');
+    };
+
     $out = array();
     foreach( $this->_markers as $name => $marker ) {
       $rec = array();
       $rec['name'] = $name;
-      $rec['position'] = array($marker->get_latitude(),$marker->get_longitude());
+      $rec['position'] = array($_fix_coord($marker->get_latitude()),$_fix_coord($marker->get_longitude()));
       if( $marker->get_icon() ) $rec['icon'] = $marker->get_icon();
       if( $marker->get_title() ) $rec['title'] = $marker->get_title();
       if( $marker->get_tooltip() ) $rec['tooltip'] = $marker->get_tooltip();
